var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { create } from "apisauce";
import appendQuery from "append-query";
const DEFAULT_API_CONFIG = {
    url: "https://api.trello.com/1",
};
export class Api {
    constructor() {
        this._ready = false;
        this._config = DEFAULT_API_CONFIG;
        this.reset = () => {
            this.setup({});
        };
        this.setHeader = (key, value) => {
            if (value) {
                this._apisauce.setHeader(key, value);
            }
            else {
                this._apisauce.deleteHeader(key);
            }
        };
        this.getLists = (boardId) => __awaiter(this, void 0, void 0, function* () {
            return yield this._apisauce.get(`/boards/${boardId}/lists/open`);
        });
        this.createCard = (name, desc, idList) => __awaiter(this, void 0, void 0, function* () {
            return yield this._apisauce.post(`/cards`, { name, desc, idList });
        });
        this.createCardAttachment = (cardId, filePath, fileName, fileType) => __awaiter(this, void 0, void 0, function* () {
            this._apisauce.setHeader("content-type", "multipart/form-data");
            const formData = new FormData();
            formData.append("name", fileName);
            formData.append("mimeType", fileType);
            formData.append("file", {
                name: fileName,
                type: fileType,
                uri: filePath,
            });
            const response = yield this._apisauce.post(`/cards/${cardId}/attachments`, formData);
            this.setHeader("content-type");
            return response;
        });
    }
    get isReady() {
        return this._ready;
    }
    get logger() {
        return this._logger;
    }
    setup(props) {
        const { key = null, token = null, logger } = props;
        if (!Boolean(key) || !Boolean(token)) {
            this._ready = false;
            return;
        }
        this._logger = logger ? logger : () => { };
        this._apisauce = create({
            baseURL: this._config.url,
            headers: {
                Accept: "application/json",
            },
        });
        this._apisauce.addRequestTransform(request => {
            request.url = appendQuery(request.url, {
                key,
                token,
            });
        });
        this._ready = true;
    }
}
//# sourceMappingURL=api.js.map