var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
//@ts-ignore
import * as React from "react";
//@ts-ignore
import { Platform } from "react-native";
import { captureScreen } from "react-native-view-shot";
import { Api } from "./api";
import { UI } from "./ui";
import { EventRegister } from "react-native-event-listeners";
import { Base64 } from "js-base64";
import DeviceInfo from "react-native-device-info";
import RNShake from "react-native-shake";
const isAndroid = Platform.OS === "android";
const isIos = Platform.OS === "ios";
const DEFAULT_OPTIONS = {
    logger: () => { },
    trelloKey: null,
    trelloToken: null,
    trelloBoardId: null,
    getState: null,
    shouldIncludeDeviceInfo: true,
};
class SnapshotForTrelloImpl {
    constructor() {
        this._isUIVisible = false;
        this._currentUIStep = "list-select";
        this._imageBase64Uri = "";
        this._imagePath = "";
        this._appState = null;
        this._deviceInfo = null;
        this._trelloLists = [];
        this._errors = [];
        this._api = new Api();
        this._isRunning = false;
        this._options = Object.assign({}, DEFAULT_OPTIONS);
        this.onStart = () => {
            if (this._isRunning) {
                this._api.setup({
                    logger: l => this.logger(l),
                    key: this._options.trelloKey,
                    token: this._options.trelloToken,
                });
                this.updateTrelloLists();
                RNShake.addEventListener("ShakeEvent", () => __awaiter(this, void 0, void 0, function* () {
                    const filePath = yield captureScreen({
                        format: "png",
                        result: "tmpfile",
                    });
                    const fileUri = yield captureScreen({
                        format: "png",
                        result: "data-uri",
                    });
                    this.onCapture(filePath, fileUri);
                }));
            }
            else {
                RNShake.removeEventListener("ShakeEvent", () => { });
            }
        };
        this.onCapture = (filePath, fileUri) => __awaiter(this, void 0, void 0, function* () {
            this._imageBase64Uri = fileUri;
            this._imagePath = filePath;
            this.getState();
            this.getDeviceInfo();
            this._isUIVisible = true;
            EventRegister.emit("RNSnapshotForTrello", this);
            this.logger(this);
        });
        this.getState = () => {
            if (!this._options.getState) {
                this._appState = null;
            }
            else {
                const state = this._options.getState();
                const stateStr = typeof state === "string" ? state : JSON.stringify(state, null, 2);
                this._appState = Base64.encode(stateStr);
            }
        };
        this.getDeviceInfo = () => {
            if (!this._options.shouldIncludeDeviceInfo) {
                this._deviceInfo = null;
            }
            else {
                const infoMapped = Object.keys(DeviceInfo)
                    .filter(k => {
                    return ![
                        isIos && "getBatteryLevel",
                        isAndroid && "getDeviceName",
                        isAndroid && "getIPAddress",
                        isAndroid && "getMACAddress",
                        isAndroid && "getPhoneNumber",
                    ].includes(k);
                })
                    .map(f => {
                    let key = f.replace("get", "");
                    key = key.charAt(0).toUpperCase() + key.slice(1);
                    try {
                        return { [key]: DeviceInfo[f]() };
                    }
                    catch (error) {
                        return {};
                    }
                });
                const infoFiltered = infoMapped.filter(o => {
                    if (o === undefined)
                        return false;
                    if (JSON.stringify(o) === "{}")
                        return false;
                    if (typeof Object.values(o)[0] === "object")
                        return false;
                    return true;
                });
                const infoMappedStrings = infoFiltered.map(info => {
                    return `${Object.keys(info)[0]}: ${Object.values(info)[0]}`;
                });
                const infoString = infoMappedStrings.join("\n");
                this._deviceInfo = Base64.encode(infoString);
            }
        };
        this.validate = () => {
            if (!Boolean(this._options.trelloKey))
                this._errors.push("Must provide a Trello API key.");
            if (!Boolean(this._options.trelloToken))
                this._errors.push("Must provide a Trello OAUTH token.");
            if (!Boolean(this._options.trelloBoardId))
                this._errors.push("Must provide a Trello board id where the snapshots will be created.");
            if (!this._isRunning)
                this._errors.push("Couldn't start because you have disabled Snapshot for Trello.");
        };
        this.updateTrelloLists = () => __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this._api.getLists(this._options.trelloBoardId);
                if (response.ok) {
                    this._trelloLists = response.data;
                    EventRegister.emit("RNSnapshotForTrello", this);
                }
                else {
                    this._errors.push(`Request failed to: ${response.config.url}`);
                }
            }
            catch (error) { }
        });
        this.changeUIStep = (step) => {
            this._currentUIStep = step;
            EventRegister.emit("RNSnapshotForTrello", this);
        };
        this.clearUI = () => {
            this._imageBase64Uri = "";
            this._imagePath = "";
            this._isUIVisible = false;
            this._appState = null;
            this._deviceInfo = null;
            this._currentUIStep = "list-select";
            EventRegister.emit("RNSnapshotForTrello", this);
        };
        this.upload = (cardName, cardDescription, listId) => __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this._api.createCard(cardName, cardDescription, listId);
                if (response.ok) {
                    return yield Promise.all([
                        this._api.createCardAttachment(response.data["id"], this._imagePath, "screenshot.jpg", "image/png"),
                        this._appState
                            ? this._api.createCardAttachment(response.data["id"], `data:text/plain;base64,${this._appState}`, "state.txt", "text/plain")
                            : null,
                        this._deviceInfo
                            ? this._api.createCardAttachment(response.data["id"], `data:text/plain;base64,${this._deviceInfo}`, "device-info.txt", "text/plain")
                            : null,
                    ]);
                }
                else {
                    this._errors.push(`Request failed to: ${response.config.url}`);
                }
            }
            catch (error) { }
        });
        this.configure = (options) => {
            const newOptions = Object.assign({}, this._options, options);
            this._options = newOptions;
            return this;
        };
        this.start = (shouldStart = true) => {
            this._isRunning = Boolean(shouldStart);
            this.validate();
            if (!this.isValid) {
                this._isRunning = false;
            }
            else {
                this.onStart();
            }
            return this;
        };
        this.getInstance = () => {
            return this;
        };
    }
    get isValid() {
        return !Boolean(this._errors.length);
    }
    get isUIVisible() {
        return this._isUIVisible;
    }
    get isRunning() {
        return this._isRunning;
    }
    get logger() {
        return this._options.logger;
    }
    get trelloLists() {
        return this._trelloLists;
    }
    get imageBase64Uri() {
        return this._imageBase64Uri;
    }
    get currentUIStep() {
        return this._currentUIStep;
    }
}
export const SnapshotForTrello = new SnapshotForTrelloImpl();
export const SnapshotForTrelloUI = SnapshotForTrello => <UI snapshot={SnapshotForTrello}/>;
//# sourceMappingURL=snapshot-for-trello.js.map