var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
//@ts-ignore
import * as React from "react";
//@ts-ignore
import { View, Keyboard, Platform, Text, TouchableOpacity, Image, TextInput, KeyboardAvoidingView, ActivityIndicator, } from "react-native";
import { EventRegister } from "react-native-event-listeners";
import RNPickerSelect from "react-native-picker-select";
const isIos = Platform.OS === "ios";
const COLORS = {
    purple900: "#484553",
    sky800: "#0082A0",
    pink900: "#96304C",
    shades500: "#676D70",
    shades800: "rgb(34,34,34)",
    shades800_8: "rgba(34,34,34,0.8)",
    red: "red",
};
const MODAL = {
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    alignItems: "center",
    justifyContent: "center",
    zIndex: 100,
    backgroundColor: COLORS.shades800_8,
};
const CONTAINER = {
    minHeight: 128,
    width: "78.66%",
    backgroundColor: "white",
    paddingTop: 24,
    paddingBottom: 16,
    paddingHorizontal: 16,
    flexDirection: "column",
    justifyContent: "flex-start",
    alignItems: "center",
    borderRadius: 8,
};
const IMAGE_CONTAINER = {
    width: "100%",
    overflow: "hidden",
    backgroundColor: "#EDEFF0",
    flexDirection: "column",
    justifyContent: "flex-start",
    alignItems: "center",
    paddingVertical: 18,
    marginBottom: 15,
};
const IMAGE = {
    width: "100%",
    height: 175,
};
const INPUT_CONTAINER = (isInvalid = false, isLast = false) => ({
    width: "100%",
    borderBottomWidth: 1,
    borderBottomColor: isInvalid ? COLORS.red : COLORS.shades800_8,
    paddingVertical: 6,
    marginBottom: isLast ? 0 : 15,
});
const INPUT = {
    fontFamily: isIos ? "Helvetica Neue" : "Roboto",
    color: COLORS.shades800,
    fontSize: 15,
    backgroundColor: "white",
};
const TEXTAREA = Object.assign({}, INPUT, { height: 120 });
const TITLE = {
    fontFamily: isIos ? "Helvetica Neue" : "Roboto",
    alignSelf: "center",
    marginBottom: 8,
    fontSize: 17,
    lineHeight: 20,
    fontWeight: "bold",
    color: COLORS.shades800,
};
const MESSAGE = {
    fontFamily: isIos ? "Helvetica Neue" : "Roboto",
    textAlign: "center",
    marginBottom: 20,
    paddingHorizontal: 5,
    fontSize: 15,
    lineHeight: 20,
    color: COLORS.shades800,
};
const BUTTON_CONTAINER = {
    marginTop: 20,
    flexDirection: "row",
};
const BUTTON = (noBorder = false) => ({
    paddingVertical: 10,
    paddingHorizontal: 4,
    borderRadius: 4,
    justifyContent: "center",
    alignItems: "center",
    flex: 1,
    borderWidth: noBorder ? 0 : 1,
    borderColor: COLORS.purple900,
    backgroundColor: "white",
});
const BUTTON_TEXT = {
    paddingHorizontal: 4,
    fontSize: 15,
    fontFamily: isIos ? "Helvetica Neue" : "Roboto",
    fontWeight: "bold",
    lineHeight: 18,
    letterSpacing: 0.2,
    color: COLORS.purple900,
};
const SELECT_CONTAINER = (isInvalid = false) => ({
    width: "100%",
    borderBottomWidth: 1,
    borderBottomColor: isInvalid ? COLORS.red : "rgba(0,0,0,0)",
});
const PICKER_SELECT = {
    inputIOS: Object.assign({}, TITLE, { fontSize: 15, paddingHorizontal: 10, width: "100%", textAlign: "center", color: COLORS.shades800 }),
};
const UPLOAD_ACTIVITY = {
    width: "100%",
    paddingVertical: 20,
};
export class UI extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            isUIVisible: false,
            isSnapshotRunning: false,
            trelloLists: [],
            imageBase64Uri: "",
            currentUIStep: "",
            listSelectValue: "",
            cardNameValue: "",
            cardDescriptionValue: "",
            isValidatingInputs: false,
            isValidatingListSelect: false,
        };
        this.componentDidMount = () => {
            this._snapshot = this.props.snapshot;
            this._eventListener = EventRegister.addEventListener("RNSnapshotForTrello", this.updateState);
        };
        this.updateState = snapshot => {
            this._snapshot = snapshot;
            this.setState({
                isUIVisible: snapshot.isUIVisible,
                isSnapshotRunning: snapshot.isRunning,
                trelloLists: snapshot.trelloLists,
                imageBase64Uri: snapshot.imageBase64Uri,
                currentUIStep: snapshot.currentUIStep,
            });
        };
        this.onCancelPress = () => {
            this._snapshot.clearUI();
            this.setState({
                cardNameValue: "",
                cardDescriptionValue: "",
                isValidatingInputs: false,
                isValidatingListSelect: false,
            });
        };
        this.onContinuePress = () => {
            this.setState({ isValidatingListSelect: true }, () => {
                const shouldContinue = Boolean(this.state.listSelectValue.length > 0);
                if (!shouldContinue)
                    return;
                this._snapshot.changeUIStep("title-description");
            });
        };
        this.onUploadPress = () => __awaiter(this, void 0, void 0, function* () {
            this.setState({ isValidatingInputs: true }, () => __awaiter(this, void 0, void 0, function* () {
                const shouldUpload = Boolean(this.state.cardNameValue.length >= 4 && this.state.cardDescriptionValue.length >= 4);
                if (!shouldUpload)
                    return;
                this._snapshot.changeUIStep("uploading");
                try {
                    yield this._snapshot.upload(this.state.cardNameValue, this.state.cardDescriptionValue, this.state.listSelectValue);
                    this.onCancelPress();
                }
                catch (error) {
                    this.onCancelPress();
                    alert("Something went wrong uploading card to Trello.");
                }
            }));
        });
    }
    componentWillUnmount() {
        EventRegister.removeEventListener(this._eventListener);
    }
    render() {
        const shouldShow = Boolean(this.state.isUIVisible && this.state.isSnapshotRunning);
        if (!shouldShow)
            return null;
        const isListSelectView = this.state.currentUIStep === "list-select";
        const isTitleDescriptionView = this.state.currentUIStep === "title-description";
        const isUploadingView = this.state.currentUIStep === "uploading";
        if (isUploadingView) {
            Keyboard.dismiss();
            return (<View style={MODAL}>
          <View style={CONTAINER}>
            <Text style={TITLE}>Upload to Trello</Text>
            <Text style={MESSAGE}>Please wait while we upload...</Text>
            <View style={UPLOAD_ACTIVITY}>
              <ActivityIndicator size="large" color={COLORS.sky800}/>
            </View>
          </View>
        </View>);
        }
        else if (isListSelectView) {
            Keyboard.dismiss();
            const isListSelectInvalid = this.state.isValidatingListSelect && this.state.listSelectValue.length === 0;
            return (<View style={MODAL}>
          <View style={CONTAINER}>
            <View style={IMAGE_CONTAINER}>
              <Image style={IMAGE} source={{
                uri: this.state.imageBase64Uri,
            }} resizeMode="contain"/>
            </View>

            <Text style={TITLE}>Upload to Trello</Text>
            <Text style={MESSAGE}>This will create a new card in the selected list.</Text>

            <View style={SELECT_CONTAINER(isListSelectInvalid)}>
              <RNPickerSelect placeholder={{
                label: "Select a list...",
                value: "",
            }} placeholderTextColor={isListSelectInvalid ? COLORS.red : COLORS.sky800} items={this.state.trelloLists.map(l => ({
                label: l.name,
                value: l.id,
            }))} onValueChange={v => {
                this.setState({
                    listSelectValue: v,
                });
            }} style={PICKER_SELECT} value={this.state.listSelectValue}/>
            </View>

            <View style={BUTTON_CONTAINER}>
              <TouchableOpacity style={BUTTON(true)} onPress={this.onCancelPress}>
                <Text style={BUTTON_TEXT}>Cancel</Text>
              </TouchableOpacity>
              <TouchableOpacity style={BUTTON(false)} onPress={this.onContinuePress}>
                <Text style={BUTTON_TEXT}>Continue</Text>
              </TouchableOpacity>
            </View>
          </View>
        </View>);
        }
        else if (isTitleDescriptionView) {
            const isCardNameInvalid = this.state.isValidatingInputs && this.state.cardNameValue.length < 4;
            const isCardDescriptionInvalid = this.state.isValidatingInputs && this.state.cardDescriptionValue.length < 4;
            return (<KeyboardAvoidingView style={MODAL} enabled behavior="padding">
          <View style={CONTAINER}>
            <Text style={TITLE}>Upload to Trello</Text>
            <Text style={MESSAGE}>Add a card title and description.</Text>

            <View style={INPUT_CONTAINER(isCardNameInvalid)}>
              <TextInput autoFocus placeholder="Card Name" placeholderTextColor={COLORS.shades500} underlineColorAndroid="white" style={INPUT} value={this.state.cardNameValue} onChangeText={r => this.setState({ cardNameValue: r })} onSubmitEditing={() => this._descriptionInputRef.focus()}/>
            </View>

            <View style={INPUT_CONTAINER(isCardDescriptionInvalid, true)}>
              <TextInput placeholder="Card Description" placeholderTextColor={COLORS.shades500} underlineColorAndroid="white" style={TEXTAREA} multiline value={this.state.cardDescriptionValue} onChangeText={r => this.setState({ cardDescriptionValue: r })} ref={r => (this._descriptionInputRef = r)}/>
            </View>

            <View style={BUTTON_CONTAINER}>
              <TouchableOpacity style={BUTTON(true)} onPress={this.onCancelPress}>
                <Text style={BUTTON_TEXT}>Cancel</Text>
              </TouchableOpacity>
              <TouchableOpacity style={BUTTON(false)} onPress={this.onUploadPress}>
                <Text style={BUTTON_TEXT}>Upload</Text>
              </TouchableOpacity>
            </View>
          </View>
        </KeyboardAvoidingView>);
        }
        else {
            return null;
        }
    }
}
//# sourceMappingURL=ui.js.map